==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebDataCloneStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDataCloneStrategyDescription } from "./WebDataCloneStrategyDescription";
/**
 * @hidden
 */
export let WebDataCloneStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDataCloneStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebDataCloneStrategyDescriptionMetadata.a == null) {
                WebDataCloneStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDataCloneStrategyDescriptionMetadata.c(WebDataCloneStrategyDescriptionMetadata.a);
            }
            if (a.k(WebDataCloneStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDataCloneStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DataCloneStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebDataCloneStrategyDescriptionMetadata.b(a);
            a.ad("WebDataCloneStrategy", () => new WebDataCloneStrategyDescription());
            a.ac("WebDataCloneStrategy", WebDataCloneStrategyDescriptionMetadata.a);
        }
    }
    WebDataCloneStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDataCloneStrategyDescriptionMetadata, 'WebDataCloneStrategyDescriptionMetadata');
    WebDataCloneStrategyDescriptionMetadata.a = null;
    return WebDataCloneStrategyDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebDataCloneStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDataCloneStrategyDescription } from "./WebDataCloneStrategyDescription";
/**
 * @hidden
 */
export let WebDataCloneStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDataCloneStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebDataCloneStrategyDescriptionMetadata.a == null) {
                WebDataCloneStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDataCloneStrategyDescriptionMetadata.c(WebDataCloneStrategyDescriptionMetadata.a);
            }
            if (a.k(WebDataCloneStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDataCloneStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DataCloneStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebDataCloneStrategyDescriptionMetadata.b(a);
            a.ae("WebDataCloneStrategy", () => new WebDataCloneStrategyDescription());
            a.ad("WebDataCloneStrategy", WebDataCloneStrategyDescriptionMetadata.a);
        }
    }
    WebDataCloneStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDataCloneStrategyDescriptionMetadata, 'WebDataCloneStrategyDescriptionMetadata');
    WebDataCloneStrategyDescriptionMetadata.a = null;
    return WebDataCloneStrategyDescriptionMetadata;
})();
